%%% System impedances
Sb = 6.25e6; % [VA], assumed value
Vb1 = 3.3e3; % [V]
Vb2 = 6.6e3; % [V]
Zb1 = (Vb1)^2/Sb; % [Ohm]
Zb2 = (Vb2)^2/Sb % [Ohm]
Ib1 = Sb/[sqrt(3)*Vb1] % [A]
Ib2 = Sb/[sqrt(3)*Vb2] % [A]
f = 100; % [Hz]
psib = [Vb2*sqrt(2)]/[2*pi*f] % [Vs], base flux linkage

%% Step-up transformer
% Base values
Sbsut = 8e6; % [VA], assumed value
Vb1sut = 3.3e3; % [V]
Vb2sut = 6.6e3; % [V]
Zb1sut = (Vb1sut)^2/Sbsut; % [Ohm]
Zb2sut = (Vb2sut)^2/Sbsut; % [Ohm]

R1sut = 0.005; % [pu]
L1sut = 0.025; % [pu]
R1sutn = R1sut*(Zb1sut/Zb1); % [pu]
X1sutn = L1sut*(Zb1sut/Zb1); % [pu]

R2sut = 0.005;
L2sut = 0.025;
X2sut = L2sut;

Rmsut = 500; % [pu]
Lmsut = 500; % [pu]
Rmsutn = Rmsut*(Zb1sut/Zb1); % [pu]
Xmsutn = Lmsut*(Zb1sut/Zb1); % [pu]

SUT = [R1sutn R2sut Rmsutn; X1sutn X2sut Xmsutn];
printmat(SUT, 'Parameters_step_up_transformer_[pu]', 'Resistance Reactance', 'Primary Secondary Magnetizing' )

%% Cable
% For 400 mm^2 XLPE cable
l = 5; %[km], cable length
Rc = 0.0470*l; % [Ohm]
Lc = 0.31e-3*l; % [H]
Cc = 0.59e-6*l; % [F]

Rcpu = Rc/Zb2; % [pu]
Xlcpu = [Lc*2*pi*f]/Zb2; % [pu]
Xccpu = [1/(2*pi*f*Cc)]/Zb2; % [pu]

C = [l; Rcpu; Xlcpu; Xccpu];
printmat(C, 'Parameters_cable_[pu]', 'Length Resistance Ind_reactance Cap_reactance', '' )

%% Induction motor
s = 0.0055; % slip, assumed value
Vllim = 6.6e3; % [V]
R1im = 0.12; % [Ohm]
L1im = 1.2469e-3; % [H]
R2im = 0.0761; % [Ohm]
L2im = L1im;
Lmim = 0.035; % [H]

R1impu = R1im/Zb2; % [pu]
X1impu = [L1im*2*pi*f]/Zb2; % [pu]
R2impu = R2im/Zb2; % [pu]
X2impu = X1impu;
Xmimpu = [Lmim*2*pi*f]/Zb2; % [pu]

Z1im = [(R2im/s) + L1im*2*pi*f*i];
Z2im = (Z1im*Lmim*2*pi*f*i)/[Z1im + Lmim*2*pi*f*i];
Z3im = Z2im + [R1im + L1im*2*pi*f*i]
Z3impu = Z3im/Zb2

Rtot = R1impu + R2impu
Xtot = X1impu + X2impu

Sim = sqrt(3)*Vllim*[conj(Vllim/Z3im)] % [VA], apparent power of the machine
Pim = real(Sim);
Qim = imag(Sim);
Angle = (cart2pol(Pim,Qim));
Angle_deg = radtodeg(Angle)
pf = cos(Angle) % power factor

IM = [R1impu R2impu 0; X1impu X2impu Xmimpu];
printmat(IM, 'Parameters_induction_motor_[pu]', 'Resistance Reactance', 'Stator Rotor Magnetizing' )

%% Permanent magnet motor
Rpm = 0.02474; % [Ohm]
Lpm = 6.1e-3; % [H]
Ipm = 600*sqrt(2) % [A]
Ipmpu = Ipm/Ib2
Ebpm = 5262; % [V], back EMF
Vcpm = [Ebpm*sqrt(2)]/[6] % [V/krpm], voltage constant
psipm = [Ebpm*sqrt(2)]/[2*pi*f]

Rpmpu = Rpm/Zb2; % [pu]
Xpmpu = [Lpm*2*pi*f]/Zb2; % [pu]
Lpmpu = Lpm/[Zb2/[2*pi*f]]; % [pu], inductance of the PM motor
Ipmpu = Ipm/Ib2; % [pu]

PM = [Rpmpu; Xpmpu];
printmat(PM, 'Parameters_permanent_magnet_motor_[pu]', 'Resistance Reactance', 'Stator' )

%%% Calculating of the equivalent impedances
ZTP = R1sutn + X1sutn*i; % [pu], primary side of the transformer
ZTM = [Rmsutn*Xmsutn*i]/[Rmsutn + Xmsutn*i]; % [pu], equivalent impedance of the magnetizing branch
ZTS = R2sut + X2sut*i; % [pu], secondary side of the transformer
ZCC1 = -Xccpu*i; % [pu]
ZCS = Rcpu + Xlcpu*i % [pu], equivalent serial impedance of the cable
ZCC2 = ZCC1;

%% Delta - star transformation
ZR = ZCS + ZCC2 + ZCC1;

ZA = [ZCS*ZCC1]/ZR;
ZB = [ZCC1*ZCC2]/ZR;
ZC = [ZCS*ZCC2]/ZR;

ZATS = ZTS + ZA;

%% Star - delta transformation
ZD = ZATS*ZC + ZC*ZB + ZB*ZATS; % [pu], denominator for the s-d transformation
ZAC = ZD/ZB;
ZAB = ZD/ZC;
ZBC = ZD/ZATS;

ZTMAB = [ZAB*ZTM]/[ZAB + ZTM];

%% Second delta - star transformation
ZR2 = ZTMAB + ZBC + ZAC;

ZA2 = [ZAC*ZTMAB]/ZR2;
ZB2 = [ZTMAB*ZBC]/ZR2;
ZC2 = [ZAC*ZBC]/ZR2;

ZA2TP = ZA2 + ZTP;

Zth = [ZA2TP*ZB2]/[ZA2TP + ZB2] + ZC2 % [pu], Thevenin impedance with detailed model

Zeq = ZTP + ZTS + ZCS % [pu], Thevenin impedance with simplified model

%% Comparison of impedance calculated with the use of detailed and simplified models
DMR = real(Zth); % real part of Thevenin impedance with detailed model
DMI = imag(Zth); % imaginary part of Thevenin impedance with detailed model
[ADM MDM]= (cart2pol(DMR,DMI)) % angle and magnitude of Thevenin impedance with detailed model

SMR = real(Zeq); % real part of Thevenin impedance with simplified model
SMI = imag(Zeq); % imaginary part of Thevenin impedance with simplified model
[ASM MSM]= (cart2pol(SMR,SMI)) % angle and magnitude of Thevenin impedance with simplified model

DC = [[MDM - MSM]/[(MDM + MSM)*0.5]]*100 % difference
