%% Initial parameters
fn = 100; % [Hz], nominal frequency
f = 0:1:100; % [Hz] starting frequency
fratio = f/fn % frequency ratio
Vtn = 6.6e3; % [V], line-to-line voltage after transformer, base voltage
Vb = 6.6e3; % [V], base voltage
Vtnph = Vtn/sqrt(3); % [V], line-to-neutral voltage after transformer
Vpu = [Vtnph*sqrt(3)]/Vb; % [pu]

%% Components parameters
% Transmission system
Zc = 0.0428 + 1i*0.1847 % [pu], impedance of transmission system
Zcs = 0.0942 + 1i*0.1792 % [pu], impedance of transmission system

% Induction motor
p = 2; % numbers of machine poles
Tstpu = 0.3; % [pu], stiction torque
Rspu = 0.01722; % [pu], stator resistance
Rrpu = 0.01092; % [pu], rotor resistance
Xspu = 0.11241; % [pu], stator reactance
Xlrpu = 0.11241; % [pu], rotor reactance
Xm = 3.15530; % [pu], magnetizing reactance
Zs = Rspu + 1i*Xspu; % [pu], stator impedance

%% Thevenin equivalent
Zth = [(Zs + Zc).*(1i*Xm)]./[Zs + Zc + 1i*Xm] % [pu], Thevenin impedance
Rth = real(Zth);
Xth = imag(Zth);

Re = (Rth + Rrpu);
Xe = (Xth + Xlrpu);

Flux = sqrt([2*Tstpu*(Re.^2+ Xe.^2)]./[3*p*Rrpu*[2.*pi.*fratio]])
Ir = sqrt([Tstpu*2*pi.*fratio]/[3*Rrpu]) % [pu], current at stiction torque

plot(f, Flux,'b', f, Ir,'g', 'LineWidth',2);

grid on
title('Flux and current curves')
ylabel('Flux [pu]  /  Current [pu]')
hleg1 = legend('Flux vs frequency','Current vs frequency');